<?php

define('NOTIFIER_THEME_NAME', 'Clockstone'); 
define('NOTIFIER_THEME_FOLDER_NAME', get_template()); 
define('NOTIFIER_XML_FILE', 'http://clockstone.cmsmasters.net/version.xml'); 
define('NOTIFIER_CACHE_INTERVAL', 21600); 


function update_notifier_menu(){
	if (function_exists('simplexml_load_string')){ 
		$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); 
		$theme_data = get_theme_data(TEMPLATEPATH.'/style.css'); 
		
		if (version_compare($xml->latest, $theme_data['Version'], '>')){ 
			add_dashboard_page(NOTIFIER_THEME_NAME.' Theme Updates', NOTIFIER_THEME_NAME.' <span class="update-plugins count-1"><span class="update-count">'.$xml->latest.'</span></span>', 'administrator', 'theme-update-notifier', 'update_notifier');
		}
	}
}
add_action('admin_menu', 'update_notifier_menu');


function update_notifier_bar_menu(){
	if (function_exists('simplexml_load_string')){ 
		global $wp_admin_bar, $wpdb;
		
		if (!is_super_admin() || !is_admin_bar_showing()){ return; }
		
		$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); 
		$theme_data = get_theme_data(TEMPLATEPATH.'/style.css'); 
		
		if (version_compare($xml->latest, $theme_data['Version'], '>')){ 
			$wp_admin_bar->add_menu(array('id' => 'update_notifier', 'title' => '<span>'.NOTIFIER_THEME_NAME.' <span id="ab-updates">'.$xml->latest.'</span></span>', 'href' => get_admin_url().'index.php?page=theme-update-notifier'));
		}
	}
}
add_action('admin_bar_menu', 'update_notifier_bar_menu', 1000);


function update_notifier(){
	$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL);
	$theme_data = get_theme_data(TEMPLATEPATH.'/style.css');

?>

<style type="text/css">
	.update-nag {display:none;}
	
	h3.title {
		border-top:1px solid #dddddd;
		padding:30px 0 0; 
		margin:30px 0 0; 
	}
</style>

<div class="wrap">
	<div id="icon-tools" class="icon32"></div>
	<h2><?php echo NOTIFIER_THEME_NAME ?> Theme Updates</h2>
	<div id="message" class="updated below-h2" style="margin-top:20px;">
		<p><strong>There is a new version of the <?php echo NOTIFIER_THEME_NAME; ?> theme available.</strong> You have version <?php echo $theme_data['Version']; ?> installed. Update to version <?php echo $xml->latest; ?>.</p>
	</div>
	<img style="float:left; margin:10px 30px 0 0; border:1px solid #dddddd;" src="<?php echo get_template_directory_uri().'/screenshot.png'; ?>" />
	<div id="instructions" style="position:relative; overflow:hidden;">
		<h3>Instructions For Downloading And Installing <?php echo NOTIFIER_THEME_NAME.' '.$xml->latest; ?></h3>
		<p><strong>Please note:</strong> make a <strong>backup</strong> of the Theme inside your WordPress installation folder <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong></p>
		<p>To update the Theme, login to <a target="_blank" href="http://www.themeforest.net/">ThemeForest</a>, head over to your <strong>downloads</strong> section and re-download the theme like you did when you bought it.</p>
		<p>Extract the zip's contents, look for the extracted theme folder, and after you have all the new files upload them using FTP to the <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong> folder overwriting the old ones (this is why it's important to backup any changes you've made to the theme files).</p>
		<p>If you didn't make any changes to the theme files, you are free to overwrite them with the new ones without the risk of losing theme settings, pages, posts, etc, and backwards compatibility is guaranteed.</p>
	</div>
	<div style="clear:both;"></div>
	<h3 class="title">Changelog</h3>
	<?php echo $xml->changelog; ?>
</div>

<?php 

}

function get_latest_theme_version($interval){
	$notifier_file_url = NOTIFIER_XML_FILE;
	$db_cache_field = 'notifier-cache';
	$db_cache_field_last_updated = 'notifier-cache-last-updated';
	$last = get_option($db_cache_field_last_updated);
	$now = time();
	
	if (!$last || (($now - $last) > $interval)){
		if (function_exists('curl_init')){ 
			$ch = curl_init();
			
            curl_setopt($ch, CURLOPT_URL, NOTIFIER_XML_FILE);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, 0);
			curl_setopt($ch, CURLOPT_TIMEOUT, 2);
			
            if (!$cache = curl_exec($ch)) $error = (curl_error($ch));
			
			curl_close($ch);
		} else {
			$cache = @file_get_contents($notifier_file_url);
		}
		
		if ($cache){
			update_option($db_cache_field, $cache);
			update_option($db_cache_field_last_updated, time());
		}
		
		$notifier_data = get_option($db_cache_field);
	} else {
		$notifier_data = get_option($db_cache_field);
	}

	if (strpos((string)$notifier_data, '<notifier>') === false){
		$notifier_data = '<?xml version="1.0" encoding="utf-8"?><notifier><latest>1.2</latest><changelog><![CDATA[<h4>Version 1.2</h4><ul><li>Added: CMSMasters form builder 1.0</li><li>Added: Internationalization (translation ready)</li><li>Added: German translation</li><li>Added: Spanish translation</li><li>Added: French translation</li><li>Added: Italian translation</li><li>Added: Polish translation</li><li>Added: Portuguese translation</li><li>Added: Russian translation</li><li>Added: Turkish translation</li><li>Added: Google Plus to sharing options</li><li>Changed: JQuery 1.6.2 to 1.6.4</li><li>Fixed: Theme update notifier issue</li><li>Fixed: Pretty permalinks issue</li></ul><br /><h4>Version 1.1.1</h4><ul><li>Added: Multisite Suuport</li><li>Added: Portfolio project content type disable parameter</li><li>Fixed: Slides categories issue</li><li>Fixed: Background manager image load issue</li></ul><br /><h4>Version 1.1</h4><ul><li>Added: Theme update notifier</li><li>Added: Wordpress 3.2 full support</li><li>Added: Awesome Flashmo slider</li><li>Added: Backgrounds manager</li><li>Added: Fantastic feature - set custom background and style (dark/light) on every page, post, project...</li><li>Added: Link target option for sliders</li><li>Changed: CMSMasters admin panel 3.5 - more productivity and with new options</li><li>Changed: Fonts manager (now you can edit and delete)</li><li>Changed: Max height of header 750px</li><li>Changed: Testimonials widget</li><li>Changed: JQuery 1.6.1 to 1.6.2</li><li>Fixed: Breadcrumbs home page link issue</li><li>Fixed: Portfolio and tags widgets</li><li>Fixed: Added mailto: for mail icon in header</li><li>Fixed: Archives</li><li>Fixed: Types and Categories issues</li><li>Fixed: Paginator on front page</li><li>Fixed: IE8 background issue</li><li>Fixed: Portfolio columns sorting issue</li><li>Fixed: Style changer background issue</li><li>Fixed: CMSMasters admin panel help lightbox issue</li><li>Fixed: Some small issues...</li></ul><br /><h4>Version 1.0.1</h4><ul><li>Fixed: CMSMasters Admin Panel Checkboxes issue</li></ul><br /><h4>Version 1.0</h4><ul><li>Released!</li></ul>]]></changelog></notifier>';
	}
	
	$xml = simplexml_load_string($notifier_data);
	
	return $xml;
}

function update_notifier_cmsms(){
	$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL);
	$theme_data = get_theme_data(TEMPLATEPATH.'/style.css');
	
?>

<tr><td>

<?php if (version_compare($xml->latest, $theme_data['Version'], '>')){ ?>

<div class="wrapper" style="position:relative; overflow:hidden;">
	<h3 style="margin:0 0 -45px;">&nbsp;</h3>
	<div id="update-message" class="updated below-h2">
		<p><strong>There is a new version of the <?php echo NOTIFIER_THEME_NAME; ?> theme available.</strong> You have version <?php echo $theme_data['Version']; ?> installed. Update to version <?php echo $xml->latest; ?>.</p>
	</div>
	<h3>Instructions For Downloading And Installing <?php echo NOTIFIER_THEME_NAME.' '.$xml->latest; ?></h3>
	<img style="float:left; margin:20px 30px 10px 0; border: 1px solid #e0e0e0;" src="<?php echo get_template_directory_uri().'/screenshot.png'; ?>" />
	<div id="instructions" style="margin-top:20px; position:relative; overflow:hidden;">
		<p><strong>Please note:</strong> make a <strong>backup</strong> of the Theme inside your WordPress installation folder <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong></p>
		<p>To update the Theme, login to <a target="_blank" href="http://www.themeforest.net/">ThemeForest</a>, head over to your <strong>downloads</strong> section and re-download the theme like you did when you bought it.</p>
		<p>Extract the zip's contents, look for the extracted theme folder, and after you have all the new files upload them using FTP to the <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong> folder overwriting the old ones (this is why it's important to backup any changes you've made to the theme files).</p>
		<p>If you didn't make any changes to the theme files, you are free to overwrite them with the new ones without the risk of losing theme settings, pages, posts, etc, and backwards compatibility is guaranteed.</p>
	</div>
</div>

<?php } ?>

<div class="wrapper">
	<h3 class="title">Changelog</h3>
	<?php echo $xml->changelog; ?>
</div>

</td></tr>

<?php } ?>
