<?php

/**
 * Flickr Widget Class
 */
class WP_Widget_Custom_Flickr extends WP_Widget {
	
	function WP_Widget_Custom_Flickr() {
		$widget_ops = array('classname' => 'widget_custom_flickr_entries', 'description' => __( "Your account most recent images") );
		$this->WP_Widget('custom-flickr', __('&nbsp;CMSMS - Flickr'), $widget_ops);
		$this->alt_option_name = 'widget_custom_flickr_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_flickr', 'widget');

		require(CMSMASTERS_CLASSES . "/var.php");
		
		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Flickr') : $instance['title'], $instance, $this->id_base);
		$usernames = apply_filters('widget_title', empty($instance['usernames']) ? __('') : $instance['usernames'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

?>
		<?php echo $before_widget; ?>
		<div class="<?php echo $widget_width; ?>">
			<div id="flickr">
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
				<div class="wrap">
					<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=<?php echo $number; ?>&amp;display=latest&amp;size=s&amp;layout=x&amp;source=user&amp;user=<?php echo $usernames; ?>"></script>        
				</div>
				<a href="http://www.flickr.com/photos/<?php echo $usernames; ?>" target="_blank"><?php _e('All Flickr Images', 'clockstone'); ?></a>
			<?php echo $after_widget; ?>
			</div>
		</div>
<?php
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_flickr', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['usernames'] = strip_tags($new_instance['usernames']);
		$instance['widget_width'] = $new_instance['widget_width'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_flickr_entries']) )
			delete_option('widget_custom_flickr_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_flickr', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$usernames = isset($instance['usernames']) ? esc_attr($instance['usernames']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 6;
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('usernames'); ?>"><?php _e('Flickr ID (<a href="http://www.idgettr.com" target="_blank">idGettr</a>):<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('usernames'); ?>" name="<?php echo $this->get_field_name('usernames'); ?>" type="text" value="<?php echo $usernames; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of recent images you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 6</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * Twitter Widget Class
 */
class WP_Widget_Custom_Twitter extends WP_Widget {
	
	function WP_Widget_Custom_Twitter() {
		$widget_ops = array('classname' => 'widget_custom_twitter_entries', 'description' => __( "Your account most recent tweets") );
		$this->WP_Widget('custom-twitter', __('&nbsp;CMSMS - Twitter'), $widget_ops);
		$this->alt_option_name = 'widget_custom_twitter_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_twitter', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Twitter') : $instance['title'], $instance, $this->id_base);
		$username = apply_filters('widget_username', empty($instance['username']) ? __('') : $instance['username'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

?>
		<?php echo $before_widget; ?>
		<script type="text/javascript">
			var tab = {
				'@<?php echo $username; ?>' : {
					'feed'		: 'http://twitter.com/statuses/user_timeline/<?php echo $username; ?>.rss',
					'function'	: twitter
				}
			}
			
			jQuery(document).ready(function(){
				jQuery('#<?php echo $args['widget_id']; ?> ul').slideDown('slow');
				
				showTab('@<?php echo $username; ?>');
			});
			
			function showTab(key){
				var obj = tab[key];
				
				if (!obj){ return false; }
				
				var stage = jQuery('#<?php echo $args['widget_id']; ?> ul');
				var query = 'select * from feed where url="'+obj.feed+'" LIMIT <?php echo $number; ?>';
				var url = 'http://query.yahooapis.com/v1/public/yql?q='+encodeURIComponent(query)+'&format=json&callback=?';
				
				jQuery.getJSON(url, function(data){
					stage.empty();
					
					jQuery.each(data.query.results.item || data.query.results.entry, function(){
						try{
							stage.append(obj['function'](this));
						}
						
						catch(e){
							var f_name =obj['function'].toString().match(/function\s+(\w+)\(/i);
							if (f_name){ f_name = f_name[1]; }
							
							stage.append('<li>There is a problem with your '+f_name+' function</li>');
							
							return false;
						}
					});
				});
			}
		</script>
		<div class="<?php echo $widget_width; ?>">
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<ul>
				<li><img src="/wp-content/themes/clockstone/images/loading_for_dark.gif" alt="Loading..." class="noimgbg" style="display:block; margin:0 auto;" /></li>
			</ul>
		</div>
		<?php echo $after_widget; ?>
<?php
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_twitter', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['username'] = strip_tags($new_instance['username']);
		$instance['widget_width'] = $new_instance['widget_width'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_twitter_entries']) )
			delete_option('widget_custom_twitter_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_twitter', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$username = isset($instance['username']) ? esc_attr($instance['username']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('username'); ?>"><?php _e('Twitter Username:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('username'); ?>" name="<?php echo $this->get_field_name('username'); ?>" type="text" value="<?php echo $username; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of recent tweets you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * Recent Comments Widget Class
 */
class WP_Widget_Custom_Recent_Comments extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Comments() {
		$widget_ops = array('classname' => 'widget_custom_comments_entries', 'description' => __( "Your site recent comments") );
		$this->WP_Widget('custom-recent-comments', __('&nbsp;CMSMS - Comments'), $widget_ops);
		$this->alt_option_name = 'widget_custom_comments_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_comments', 'widget');

		require(CMSMASTERS_CLASSES . "/var.php");
		
		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Comments') : $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		global $wpdb;
		$now = gmdate("Y-m-d H:i:s",time());
		$lastmonth = gmdate("Y-m-d H:i:s",gmmktime(date("H"), date("i"), date("s"), date("m")-12,date("d"),date("Y")));
		$r = "SELECT pp.ID, 
					   pp.post_title, 
					   pp.guid, 
					   cc.comment_ID AS 'stammy',
					   cc.comment_ID,
					   cc.comment_author,
					   cc.comment_date,
					   cc.comment_content
				  FROM $wpdb->posts AS pp
				  INNER JOIN $wpdb->comments AS cc 
					ON (
						(pp.ID = cc.comment_post_ID)
						AND
						(cc.comment_approved = '1')
						AND
						(cc.comment_date < '$now') 
						AND 
						(cc.comment_date > '$lastmonth')
					   )
				  WHERE (
						(pp.post_type = 'post')
						AND
						(pp.post_status = 'publish') 
						AND 
						(pp.comment_status = 'open')
						)
				  GROUP BY cc.comment_ID
				  ORDER BY stammy DESC LIMIT ".$number;
		$rcomments = $wpdb->get_results($r);

	  if ($rcomments) :
?>
		<?php echo $before_widget; ?>
		<div class="<?php echo $widget_width; ?>">
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<ul>	
			<?php foreach($rcomments as $comment){ 
				$comment_author = $comment->comment_author;
				$post_title = $comment->post_title;
				$post_link = $comment->guid;
				$comment_date = $comment->comment_date;
				$comment_date = mysql2date('F j, Y g:i A', $comment_date, false);
				$comment_content = $comment->comment_content; ?>
				<li>
					<strong><?php echo $comment_author; ?></strong> <?php _e('on', 'clockstone'); ?> <a href="<?php echo $post_link; ?>#comments" rel="bookmark"><?php echo $post_title; ?></a><br />
					<span class="trans">(<?php echo $comment_date; ?>)</span><br />
					<?php the_content_limit2($comment_content, 70, ""); ?>
				</li>
			<?php } ?>
			</ul>
		</div>
		<?php echo $after_widget; ?>
<?php

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['widget_width'] = $new_instance['widget_width'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_recent_entries']) )
			delete_option('widget_custom_recent_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of recent posts you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
				
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * Popular Posts/News Widget Class
 */
class WP_Widget_Custom_Popular_Posts extends WP_Widget {
	
	function WP_Widget_Custom_Popular_Posts() {
		$widget_ops = array('classname' => 'widget_custom_popular_entries', 'description' => __( "Most popular posts/news on your site") );
		$this->WP_Widget('custom-popular-posts', __('&nbsp;CMSMS - Popular Posts/News'), $widget_ops);
		$this->alt_option_name = 'widget_custom_popular_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_popular_posts', 'widget');

		require(CMSMASTERS_CLASSES . "/var.php");
		
		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);
		
		if ( !$post_type = $instance['post_type'] )
			$post_type = 'post';
		if ($post_type == 'news'){
			$title = apply_filters('widget_title', empty($instance['title']) ? __('Popular News') : $instance['title'], $instance, $this->id_base);
		} else {
			$title = apply_filters('widget_title', empty($instance['title']) ? __('Popular Posts') : $instance['title'], $instance, $this->id_base);			
		}
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => $post_type, 'orderby' => 'comment_count'));
		
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<div class="<?php echo $widget_width; ?>">
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<ul>
			<?php  while ($r->have_posts()) : $r->the_post(); ?>
				<?php $comment_count = get_comments_number(); ?>
				<?php if ( $comment_count > 0 ) { ?>
					<li>
						<?php if ( has_post_thumbnail() ) { ?>
							<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" class="fl">
								<span class="image_shadow_container">
									<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_image_path(get_the_ID()); ?>&amp;w=90&amp;h=90&amp;zc=1" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" class="image_shadow" />
									<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_template_directory_uri(); ?>/images/image_shadow.png&amp;w=100" alt="" class="noimgbg" />
								</span>
							</a>
						<?php } ?>
						<div class="ovh">
							<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a><br />
							<span><?php the_content_limit2(get_the_content(), 70, ''); ?></span>
						</div>
					</li>
				<?php } ?>
			<?php endwhile; ?>
			</ul>
		</div>
		<?php echo $after_widget; ?>
<?php
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_popular_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['post_type'] = $new_instance['post_type'];
		$instance['widget_width'] = $new_instance['widget_width'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_popular_entries']) )
			delete_option('widget_custom_popular_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_popular_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['post_type']) || !$post_type = $instance['post_type'] )
			$post_type = 'post';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('post_type'); ?>">
		<select id="<?php echo $this->get_field_id('post_type'); ?>" name="<?php echo $this->get_field_name('post_type'); ?>" style="float:right; margin-top:8px;">
			<option <?php if ($post_type == 'post'){ echo ' selected="selected"'; } ?>value="post">Posts&nbsp;</option>
			<option <?php if ($post_type == 'news'){ echo ' selected="selected"'; } ?>value="news">News&nbsp;</option>
		</select>
		<?php _e('<span style="floar:left; line-height:3em;">Choose data type:</span>'); ?></label></p>
		<div style="clear:both;"></div>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of popular posts you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * Recent Posts/News Widget Class
 */
class WP_Widget_Custom_Recent_Posts extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Posts() {
		$widget_ops = array('classname' => 'widget_custom_recent_entries', 'description' => __( "The most recent posts/news on your site") );
		$this->WP_Widget('custom-recent-posts', __('&nbsp;CMSMS - Recent Posts/News'), $widget_ops);
		$this->alt_option_name = 'widget_custom_recent_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_posts', 'widget');

		require(CMSMASTERS_CLASSES . "/var.php");
		
		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		if ( !$post_type = $instance['post_type'] )
			$post_type = 'post';
		if ($post_type == 'news'){
			$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent News') : $instance['title'], $instance, $this->id_base);
		} else {
			$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title'], $instance, $this->id_base);			
		}
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;
		
		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => $post_type));
		
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<div class="<?php echo $widget_width; ?>">
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<ul>
			<?php  while ($r->have_posts()) : $r->the_post(); ?>
				<li>
					<?php if ( has_post_thumbnail() ) { ?>
						<span class="image_shadow_container alignleft">
							<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">
								<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_image_path(get_the_ID()); ?>&amp;w=50&amp;h=50&amp;zc=1" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" class="image_shadow" />
							</a>
							<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_template_directory_uri(); ?>/images/image_shadow.png&amp;w=60" alt="" class="noimgbg" />
						</span>
					<?php } ?>
					<div style="padding-bottom:15px;">
						<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a><br />
						<small><?php the_time('F d, Y'); ?></small>
					</div>
					<div class="cl"></div>
					<div><?php the_content_limit2(get_the_content(), 110, ''); ?></div>
				</li>
			<?php endwhile; ?>
			</ul>
		</div>
		<?php echo $after_widget; ?>
<?php
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['post_type'] = $new_instance['post_type'];
		$instance['widget_width'] = $new_instance['widget_width'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_recent_entries']) )
			delete_option('widget_custom_recent_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['post_type']) || !$post_type = $instance['post_type'] )
			$post_type = 'post';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('post_type'); ?>">
		<select id="<?php echo $this->get_field_id('post_type'); ?>" name="<?php echo $this->get_field_name('post_type'); ?>" style="float:right; margin-top:8px;">
			<option <?php if ($post_type == 'post'){ echo ' selected="selected"'; } ?>value="post">Posts&nbsp;</option>
			<option <?php if ($post_type == 'news'){ echo ' selected="selected"'; } ?>value="news">News&nbsp;</option>
		</select>
		<?php _e('<span style="floar:left; line-height:3em;">Choose data type:</span>'); ?></label></p>
		<div style="clear:both;"></div>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of recent posts you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Recent Testimonials Widget Class
 */
class WP_Widget_Custom_Recent_Testimonials extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Testimonials() {
		$widget_ops = array('classname' => 'widget_custom_testimonials_entries', 'description' => __( "The recent testimonials on your site") );
		$this->WP_Widget('custom-recent-testimonials', __('&nbsp;CMSMS - Recent Testimonials'), $widget_ops);
		$this->alt_option_name = 'widget_custom_testimonials_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_testimonials', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Testimonials') : $instance['title'], $instance, $this->id_base);
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;
		if ( !$symbols = (int) $instance['symbols'] )
			$symbols = 150;
		else if ( $symbols < 50 )
			$symbols = 50;
		else if ( $symbols > 1000 )
			$symbols = 1000;

		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => 'testimonials'));
		if ($r->have_posts()) :
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<?php echo $before_widget; ?>
		
		<div class="<?php echo $widget_width; ?>">
		
		<div class="test_widget">
			<script type="text/javascript">
				jQuery(window).load(function(){
					jQuery('#<?php echo $args['widget_id']; ?> .widget_custom_testimonials_entries_container').slides({
						container:'widget_custom_testimonials_entries_slides',
						pagination:false,
						generatePagination:false,
						next: 'next',
						prev: 'prev',
						slideSpeed:500,
						play:5000,
						pause:5000,
						hoverPause:true,
						autoHeight:true,
						autoHeightSpeed:500
					});
				});
			</script>
			<div class="widget_custom_testimonials_entries_container">
				<div class="nav">
					<?php if ( $title ) echo $before_title . $title . $after_title; ?>
					<div class="nav_box">
						<a href="#" class="next"></a>
						<a href="#" class="prev"></a>
					</div>
				</div>
				<div class="cl"></div>
				<ul class="thumbnail_list widget_custom_testimonials_entries_slides">
				<?php 
					while ($r->have_posts()) : $r->the_post();
						$post = get_post( get_the_ID() ); 
						$test_author_descr = get_post_meta( $post->ID, 'author_subtitle', true ); 
				?>
					<li>
						<div class="test_top"><div class="test_top_l"></div><div class="test_top_r"></div><div class="test_top_c"></div></div><div class="test_mid_l"><div class="test_mid_r"><div class="test_mid_c">
							<?php the_content_limit2(get_the_content(), $symbols, ""); ?>
						</div></div></div><div class="test_bot"><div class="test_bot_l"></div><div class="test_bot_r"></div><div class="test_bot_c"></div></div>
						<span>
							<a href="<?php the_permalink(); ?>"><strong><?php the_title(); ?></strong><?php if ($test_author_descr){ ?><br /><?php echo $test_author_descr; } ?></a>
						</span>
					</li>
				<?php endwhile; ?>
				</ul>
			</div>
		</div>
		<?php
		echo '</div>';
		echo $after_widget; ?>
<?php
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_testimonials', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['symbols'] = (int) $new_instance['symbols'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_testimonials_entries']) )
			delete_option('widget_custom_testimonials_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_testimonials', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
		if ( !isset($instance['symbols']) || !$symbols = (int) $instance['symbols'] )
			$symbols = 150;
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of recent testimonials you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>

		<p><label for="<?php echo $this->get_field_id('symbols'); ?>"><?php _e('Enter the number of symbols you\'d like to display in testimonials:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('symbols'); ?>" name="<?php echo $this->get_field_name('symbols'); ?>" type="text" value="<?php echo $symbols; ?>" size="5" /><small style="color:#f00; float:right; padding-top:2px;">default is 150</small><br /></label></p>

		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Latest Products Widget Class
 */
class WP_Widget_Custom_Recent_Products extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Products() {
		$widget_ops = array('classname' => 'widget_custom_products_entries', 'description' => __( "The latest products on your site") );
		$this->WP_Widget('custom-recent-products', __('&nbsp;CMSMS - Latest Products'), $widget_ops);
		$this->alt_option_name = 'widget_custom_products_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_products', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Products') : $instance['title'], $instance, $this->id_base);
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => 'products'));
		if ($r->have_posts()) :
?>
		<?php if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget; ?>
		
		<div class="<?php echo $widget_width; ?>">
		
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<script type="text/javascript">
				jQuery(window).load(function(){
					jQuery('#<?php echo $args['widget_id']; ?> .widget_custom_products_entries_container').slides({
						container:'widget_custom_products_entries_slides',
						pagination:true,
						generatePagination:true,
						paginationClass:'widget_custom_products_entries_pager',
						slideSpeed:500,
						play:5000,
						pause:5000,
						hoverPause:true,
						autoHeight:true,
						autoHeightSpeed:500
					});
				});
			</script>
		<div class="widget_custom_products_entries_container">
			<ul class="thumbnail_list widget_custom_products_entries_slides">
			<?php  while ($r->have_posts()) : $r->the_post(); ?>
				<li>
					<p>
						<?php if ( has_post_thumbnail() ) { ?>
							<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">
								<img class="noimgbg" src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_image_path(get_the_ID()); ?>&amp;w=200&amp;h=200&amp;zc=1" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" />
							</a>
						<?php } ?>
					</p>
					<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
				</li>
			<?php endwhile; ?>
			</ul>
		</div>
		<?php echo '</div>'; echo $after_widget; ?>
<?php
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_products', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_products_entries']) )
			delete_option('widget_custom_products_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_products', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of latest products you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
		<?php
	}
}


/**
 * Latest Portfolio Items Widget Class
 */
class WP_Widget_Custom_Recent_Portfolio extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Portfolio() {
		$widget_ops = array('classname' => 'widget_custom_portfolio_entries', 'description' => __( "The latest portfolio items on your site") );
		$this->WP_Widget('custom-recent-portfolio', __('&nbsp;CMSMS - Portfolio Items'), $widget_ops);
		$this->alt_option_name = 'widget_custom_portfolio_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_portfolio', 'widget');
		
		if ( !is_array($cache) )
			$cache = array();
		
		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}
		
		ob_start();
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Portfolio Items') : $instance['title'], $instance, $this->id_base);			
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;
		
		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => 'portfolio'));
		if ($r->have_posts()) :
		
		echo $before_widget; ?>
		
		<div class="<?php echo $widget_width; ?>">
			<script type="text/javascript">
				jQuery(window).load(function(){
					jQuery('#<?php echo $args['widget_id']; ?> .widget_custom_portfolio_entries_container').slides({
						container:'widget_custom_portfolio_entries_slides',
						pagination:false,
						generatePagination:false,
						next:'next',
						prev:'prev',
						slideSpeed:500,
						play:5000,
						pause:5000,
						hoverPause:true,
						autoHeight:true,
						autoHeightSpeed:500
					});
				});
			</script>
			<div class="widget_custom_portfolio_entries_container">
				<div class="nav">
					<?php if ( $title ) echo $before_title . $title . $after_title; ?>
					<div class="nav_box">
						<a href="#" class="next"></a>
						<a href="#" class="prev"></a>
						<div class="cl"></div>
					</div>
				</div>
				<div class="cl"></div>
				<ul class="thumbnail_list widget_custom_portfolio_entries_slides">
				<?php  while ($r->have_posts()) : $r->the_post(); ?>
					<li>
						<?php if (has_post_thumbnail()){ ?>
							<p style="padding-bottom:10px;">
								<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">
									<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_image_path(get_the_ID()); ?>&amp;w=257&amp;h=130&amp;zc=1" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" />
								</a>
							</p>
						<?php } ?>
						<p><a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a></p>
					</li>
				<?php endwhile; ?>
				</ul>
			</div>
		</div>
		<?php echo $after_widget;
		
		wp_reset_postdata();
		
		endif;
		
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_portfolio', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_portfolio_entries']) )
			delete_option('widget_custom_portfolio_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_portfolio', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 3;
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of latest portfolio items you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Latest Gallery Items Widget Class
 */
class WP_Widget_Custom_Recent_Gallery extends WP_Widget {
	
	function WP_Widget_Custom_Recent_Gallery() {
		$widget_ops = array('classname' => 'widget_custom_gallery_entries', 'description' => __( "The latest gallery items on your site") );
		$this->WP_Widget('custom-recent-gallery', __('&nbsp;CMSMS - Gallery Items'), $widget_ops);
		$this->alt_option_name = 'widget_custom_gallery_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_recent_gallery', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Latest Gallery Items') : $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		if ( !$items = (int) $instance['items'] )
			$items = 10;
		else if ( $items < 1 )
			$items = 1;
		else if ( $items > 15 )
			$items = 15;
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$r = new WP_Query(array('posts_per_page' => $number, 'post_status' => 'publish', 'caller_get_posts' => 1, 'post_type' => 'gallery'));
		if ($r->have_posts()) :
		
		echo $before_widget; ?>
			
		<div class="<?php echo $widget_width; ?>">
			<?php 
				$numb = 0;
				while ($r->have_posts()) : $r->the_post();
					$numb = $numb + 1;
				endwhile;
			?>
			<?php if ($items < $numb){ ?>
			<script type="text/javascript">
				jQuery(window).load(function(){
					jQuery('#<?php echo $args['widget_id']; ?> .widget_custom_gallery_entries_container').slides({
						container:'widget_custom_gallery_entries_slides',
						pagination:false,
						generatePagination:false,
						next: 'next',
						prev: 'prev',
						slideSpeed:500,
						play:5000,
						pause:5000,
						hoverPause:true,
						autoHeight:true,
						autoHeightSpeed:500
					});
				});
			</script>
			<?php } ?>
			<div class="widget_custom_gallery_entries_container">
				<div class="nav">
					<?php if ( $title ) echo $before_title . $title . $after_title; ?>
				<?php if ($items < $numb){ ?>
					<div class="nav_box">
						<a href="#" class="next"></a>
						<a href="#" class="prev"></a>
					</div>
				<?php } ?>
				</div>
				<div class="cl"></div>
				<ul class="thumbnail_list widget_custom_gallery_entries_slides">
				<?php $itemscount = 0; ?>
					<li<?php if ($items > $numb){ echo ' style="display:block;"'; } ?>>
						<?php while ($r->have_posts()) : $r->the_post(); ?>
							<?php 
								if ($itemscount > $items-1){
									echo '</li><li>';
									$itemscount = 0;
								}
							?>
							<?php if (has_post_thumbnail()){ ?>
								<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">
									<img src="<?php echo get_template_directory_uri(); ?>/theme/classes/timthumb.php?src=<?php echo get_image_path(get_the_ID()); ?>&amp;w=70&amp;h=70&amp;zc=1" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" />
								</a>
							<?php } else { ?>
								<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">
									<img src="<?php echo get_template_directory_uri(); ?>/images/gal-widget-placeholder.jpg" alt="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>" />
								</a>
							<?php } ?>
							<?php $itemscount++; ?>
						<?php endwhile; ?>
					</li>
				</ul>
			</div>
		</div>
		<?php echo $after_widget;
		
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_recent_gallery', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['items'] = (int) $new_instance['items'];
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_gallery_entries']) )
			delete_option('widget_custom_gallery_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_recent_gallery', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['items']) || !$items = (int) $instance['items'] )
			$items = 3;
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 9;
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Enter the number of latest gallery items you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 9</small><br /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('items'); ?>"><?php _e('Enter the number of latest gallery items per slide:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('items'); ?>" name="<?php echo $this->get_field_name('items'); ?>" type="text" value="<?php echo $items; ?>" size="3" /><small style="color:#f00; float:right; padding-top:2px;">default is 3</small><br /></label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Contact Information Widget Class
 */
class WP_Widget_Custom_Contact_Info extends WP_Widget {
	
	function WP_Widget_Custom_Contact_Info() {
		$widget_ops = array('classname' => 'widget_custom_contact_info_entries', 'description' => __( "Your contact information") );
		$this->WP_Widget('custom-contact-info', __('&nbsp;CMSMS - Contact Information'), $widget_ops);
		$this->alt_option_name = 'widget_custom_contact_info_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_contact_info', 'widget');

		require(CMSMASTERS_CLASSES . "/var.php");

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Contact Information') : $instance['title'], $instance, $this->id_base);
		$name = apply_filters('widget_title', empty($instance['name']) ? __('') : $instance['name'], $instance, $this->id_base);
		$address = apply_filters('widget_title', empty($instance['address']) ? __('') : $instance['address'], $instance, $this->id_base);
		$city = apply_filters('widget_title', empty($instance['city']) ? __('') : $instance['city'], $instance, $this->id_base);
		$state = apply_filters('widget_title', empty($instance['state']) ? __('') : $instance['state'], $instance, $this->id_base);
		$zip = apply_filters('widget_title', empty($instance['zip']) ? __('') : $instance['zip'], $instance, $this->id_base);
		$phone = apply_filters('widget_title', empty($instance['phone']) ? __('') : $instance['phone'], $instance, $this->id_base);
		$email = apply_filters('widget_title', empty($instance['email']) ? __('') : $instance['email'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
			
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
			if ( $title ) echo $before_title . $title . $after_title;
			
			if ($name != ''){
				echo '<span class="contact_widget_name">'.$name.'</span><br />';
			}
			
			if ($address != ''){
				echo '<span class="contact_widget_address">'.$address.'</span><br />';
			}
				
			if ($city != ''){
				echo '<span class="contact_widget_city">'.$city.'</span>';
			}
				
			if ($state != ''){
				echo '<span class="contact_widget_state">,&nbsp;'.$state.'</span>&nbsp;';
			}

			if ($zip != ''){
				echo '<span class="contact_widget_zip">'.$zip.'</span><br /><br />';
			}

			if ($phone != ''){
				echo '<span class="contact_widget_phone"><span style="display:inline-block; width:80px;">'.__('Phone', 'clockstone').':&nbsp;</span>'.$phone.'</span><br />';
			}
			
			if ($email != ''){
				echo '<span class="contact_widget_email"><span style="display:inline-block; width:80px;">'.__('Email', 'clockstone').':&nbsp;</span><a href="mailto:'.$email.'">'.$email.'</a></span><br />';
			}
		echo '</div>';
		echo $after_widget;
			
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_contact_info', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['name'] = strip_tags($new_instance['name']);
		$instance['address'] = strip_tags($new_instance['address']);
		$instance['city'] = strip_tags($new_instance['city']);
		$instance['state'] = strip_tags($new_instance['state']);
		$instance['zip'] = strip_tags($new_instance['zip']);
		$instance['phone'] = strip_tags($new_instance['phone']);
		$instance['email'] = strip_tags($new_instance['email']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_contact_info_entries']) )
			delete_option('widget_custom_contact_info_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_contact_info', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$name = isset($instance['name']) ? esc_attr($instance['name']) : '';
		$address = isset($instance['address']) ? esc_attr($instance['address']) : '';
		$city = isset($instance['city']) ? esc_attr($instance['city']) : '';
		$state = isset($instance['state']) ? esc_attr($instance['state']) : '';
		$zip = isset($instance['zip']) ? esc_attr($instance['zip']) : '';
		$phone = isset($instance['phone']) ? esc_attr($instance['phone']) : '';
		$email = isset($instance['email']) ? esc_attr($instance['email']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('name'); ?>"><?php _e('Name:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('name'); ?>" name="<?php echo $this->get_field_name('name'); ?>" type="text" value="<?php echo $name; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('address'); ?>"><?php _e('Address:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('address'); ?>" name="<?php echo $this->get_field_name('address'); ?>" type="text" value="<?php echo $address; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('city'); ?>"><?php _e('City:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('city'); ?>" name="<?php echo $this->get_field_name('city'); ?>" type="text" value="<?php echo $city; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('state'); ?>"><?php _e('State:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('state'); ?>" name="<?php echo $this->get_field_name('state'); ?>" type="text" value="<?php echo $state; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('zip'); ?>"><?php _e('Zip:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('zip'); ?>" name="<?php echo $this->get_field_name('zip'); ?>" type="text" value="<?php echo $zip; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('phone'); ?>"><?php _e('Phone:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('phone'); ?>" name="<?php echo $this->get_field_name('phone'); ?>" type="text" value="<?php echo $phone; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('email'); ?>"><?php _e('Email:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('email'); ?>" name="<?php echo $this->get_field_name('email'); ?>" type="text" value="<?php echo $email; ?>" /></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Contact Form Widget Class
 */
class WP_Widget_Custom_Contact_Form extends WP_Widget {
	function WP_Widget_Custom_Contact_Form() {
		$widget_ops = array('classname' => 'widget_custom_contact_form_entries', 'description' => __( "Your website contact form") );
		$this->WP_Widget('custom-contact-form', __('&nbsp;CMSMS - Contact Form'), $widget_ops);
		$this->alt_option_name = 'widget_custom_contact_form_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		global $wpdb, $shortname;
		require(CMSMASTERS_CLASSES.'/var.php');
		
		$cache = wp_cache_get('widget_custom_contact_form', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Contact Us') : $instance['title'], $instance, $this->id_base);
		$email = apply_filters('widget_title', empty($instance['email']) ? __('') : $instance['email'], $instance, $this->id_base);
		if ( !$formname = $instance['formname'] )
			$formname = '';
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title ) echo $before_title . $title . $after_title;
			
			$email_adress_reciever = $email != '' ? $email : '';
			
			if ($wpdb->get_var("SELECT id FROM ".$wpdb->prefix.$shortname."_forms WHERE type = 'form' AND parent_slug = '".$formname."'") != ''){
				$results = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix.$shortname."_forms WHERE parent_slug='".$formname."' ORDER BY number ASC");
				
				foreach ($results as $form_result){
					if ($form_result->type == 'form'){
						$success = explode('{|%|}', $form_result->description);
						
						$out = '<div class="cmsms-form-builder">'.
							'<div class="widgetinfo">'.$success[1].'</div>'.
							'<script type="text/javascript">'.
								'jQuery(document).ready(function(){'.
									"jQuery('#form_".$formname."').validationEngine('init');".
									"jQuery('#form_".$formname." a#".$formname."_wformsend').click(function(){".
										'var $'.$formname.'form_builder_email = '."jQuery('#".$formname."_wemail').val();".
										'var $'.$formname.'form_builder_url = '."jQuery('#".$formname."_wurl').val();".
										"jQuery('#form_".$formname." .loading').animate({opacity:1}, 250);";
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type == 'checkbox'){
						$out .= "var $var_".$form_result->slug." = ''; jQuery('input[name=\'".$form_result->slug."\']:checked').each(function(){ $var_".$form_result->slug." += jQuery(this).val(); });";
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type == 'checkboxes'){
						$out .= "var $var_".$form_result->slug." = ''; jQuery('input[name=\'".$form_result->slug."\']:checked').each(function(){ $var_".$form_result->slug." += jQuery(this).val()+', '; }); if ($var_".$form_result->slug." != ''){ $var_".$form_result->slug." = $var_".$form_result->slug.".slice(0, -2); }";
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type == 'form'){
						$out .= "if (jQuery('#form_".$formname."').validationEngine('validate')){".
							'jQuery.post($'.$formname.'form_builder_url, {';
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type != 'form'){
						if ($form_result->type == 'checkboxes' || $form_result->type == 'checkbox'){
							$out .= $form_result->slug.":$var_".$form_result->slug.",";
						} else if ($form_result->type == 'radiobutton'){
							$out .= $form_result->slug.":jQuery('input[name=\'".$form_result->slug."\']:checked').val(),";
						} else {
							$out .= $form_result->slug.":jQuery('#".$form_result->slug."').val(),";
						}
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type == 'form'){
						$out .= 'contactemail:$'.$formname.'form_builder_email,'.
										"formname:'".$formname."'".
									'}, function(data){'.
										"jQuery('#form_".$formname." .loading').animate({opacity:0}, 250);".
										"document.getElementById('form_".$formname."').reset();".
										"jQuery('#form_".$formname."').parent().find('.widgetinfo').hide();".
										"jQuery('#form_".$formname."').parent().find('.widgetinfo').fadeIn('fast');".
										"jQuery('html, body').animate({scrollTop:jQuery('#form_".$formname."').offset().top - 100}, 'slow');".
										"jQuery('#form_".$formname."').parent().find('.widgetinfo').delay(5000).fadeOut(1000);".
									'});'.
										'return false;'.
									'} else {'.
										"jQuery('#form_".$formname." .loading').animate({opacity:0}, 250);".
										'return false;'.
									'}'.
								'});'.
							'});'.
						'</script>'.
						'<form action="#" method="post" id="form_'.$formname.'">';
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type != 'form'){
						$field_label = $form_result->label;
						$field_name = $form_result->slug;
						$vals = explode('|', $form_result->value);
						$params = $form_result->parameters;
						$params_explode = explode(',', $params);
						
						$required_label = (str_replace('required', '', $params) != $params) ? ' <span class="yellow">*</span>' : '';
						
						$required = (str_replace('required', '', $params) != $params) ? 'required,' : '';
						
						if (str_replace('minSize', '', $params) != $params){
							for ($n = 0; $n < sizeof($params_explode); $n++){
								if (str_replace('minSize', '', $params_explode[$n]) != $params_explode[$n]) $minSize = 'minSize['.str_replace('minSize[', '', str_replace(']', '', $params_explode[$n])).'],';
							}
						} else {
							$minSize = '';
						}
						
						if (str_replace('maxSize', '', $params) != $params){
							for ($x = 0; $x < sizeof($params_explode); $x++){
								if (str_replace('maxSize', '', $params_explode[$x]) != $params_explode[$x]) $maxSize = 'maxSize['.str_replace('maxSize[', '', str_replace(']', '', $params_explode[$x])).'],';
							}
						} else {
							$maxSize = '';
						}
						
						$customEmail = (str_replace('custom[email]', '', $params) != $params) ? 'custom[email],' : '';
						
						$customUrl = (str_replace('custom[url]', '', $params) != $params) ? 'custom[url],' : '';
						
						$customNumber = (str_replace('custom[number]', '', $params) != $params) ? 'custom[number],' : '';
						
						$customOnlyNumberSp = (str_replace('custom[onlyNumberSp]', '', $params) != $params) ? 'custom[onlyNumberSp],' : '';
						
						$customOnlyLetterSp = (str_replace('custom[onlyLetterSp]', '', $params) != $params) ? 'custom[onlyLetterSp],' : '';
						
						$validate_val = $required.$minSize.$maxSize.$customEmail.$customUrl.$customNumber.$customOnlyNumberSp.$customOnlyLetterSp;
						
						$validate = ($validate_val != '') ? ' class="validate['.substr($validate_val, 0, -1).']"' : '';
						
						$descr = ($form_result->description != '' && $form_result->description != ' ') ? '<small>'.$form_result->description.'</small>' : '';
						
						switch ($form_result->type){
							case 'text':
								$out .= '<div class="form_info cmsms_input">'.
									'<label for="'.$field_name.'"><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									'<div class="inp_l">'.
										'<div class="inp_r">'.
											'<input type="text" name="'.$field_name.'" id="'.$field_name.'" value=""'.$validate.' />'.
										'</div>'.
									'</div>'.
									$descr.
								'</div>'.
								'<div class="cl"></div>';
							break;
							case 'email':
								$out .= '<div class="form_info cmsms_input">'.
									'<label for="'.$field_name.'"><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									'<div class="inp_l">'.
										'<div class="inp_r">'.
											'<input type="text" name="'.$field_name.'" id="'.$field_name.'" value=""'.$validate.' />'.
										'</div>'.
									'</div>'.
									$descr.
								'</div>'.
								'<div class="cl"></div>';
							break;
							case 'textarea':
								$out .= '<div class="form_info cmsms_textarea">'.
									'<label for="'.$field_name.'"><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									'<table>'.
										'<tbody>'.
											'<tr>'.
												'<td class="text_t_l"></td>'.
												'<td class="text_t"></td>'.
												'<td class="text_t_r"></td>'.
											'</tr>'.
											'<tr>'.
												'<td class="text_l"></td>'.
												'<td class="text_m">'.
													'<textarea name="'.$field_name.'" id="'.$field_name.'" cols="58" rows="6"'.$validate.'></textarea>'.
												'</td>'.
												'<td class="text_r"></td>'.
											'</tr>'.
											'<tr>'.
												'<td class="text_b_l"></td>'.
												'<td class="text_b"></td>'.
												'<td class="text_b_r"></td>'.
											'</tr>'.
										'</tbody>'.
									'</table>'.
									$descr.
								'</div>'.
								'<div class="cl"></div>';
							break;
							case 'dropdown':
								$out .= '<div class="form_info cmsms_select">'.
									'<label><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									'<div class="inp_l">'.
										'<div class="inp_r">'.
											'<select name="'.$field_name.'" id="'.$field_name.'"'.$validate.'>';
											
											foreach ($vals as $val){
												$out .= '<option value="'.$val.'">'.$val.'</option>';
											}
											
											$out .= '</select>'.
										'</div>'.
									'</div>'.
									'<div class="cl"></div>'.
									$descr.
								'</div>'.
								'<div class="cl"></div>';
							break;
							case 'radiobutton':
								$out .= '<div class="form_info cmsms_radio">'.
									'<label><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									$descr;
									
									$i = 1;
									
									foreach ($vals as $val){
										$out .= '<div class="check_parent">'.
											'<input type="radio" name="'.$field_name.'" id="'.$field_name.$i.'" value="'.$val.'"'.$validate.' />'.
											'<label for="'.$field_name.$i.'">'.$val.'</label>'.
										'</div>'.
										'<div class="cl"></div>';
										
										$i++;
									}
									
								$out .= '</div>'.
								'<div class="cl"></div>';
							break;
							case 'checkbox':
								$out .= '<div class="form_info cmsms_checkboxes">'.
									'<label><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									$descr.
									'<div class="check_parent">'.
										'<input type="checkbox" name="'.$field_name.'" id="'.$field_name.'" value="'.$vals[0].'"'.$validate.' />'.
										'<label for="'.$field_name.'">'.$vals[0].'</label>'.
									'</div>'.
									'<div class="cl"></div>'.
								'</div>'.
								'<div class="cl"></div>';
							break;
							case 'checkboxes':
								$out .= '<div class="form_info cmsms_checkboxes">'.
									'<label><strong>'.$field_label.'</strong>'.$required_label.'</label>'.
									$descr;
									
									$i = 1;
									
									foreach ($vals as $val){
										$out .= '<div class="check_parent">'.
											'<input type="checkbox" name="'.$field_name.'" id="'.$field_name.$i.'" value="'.$val.'" />'.
											'<label for="'.$field_name.$i.'">'.$val.'</label>'.
										'</div>'.
										'<div class="cl"></div>';
										
										$i++;
									}
									
								$out .= '</div>'.
								'<div class="cl"></div>';
							break;
						}
					}
				}
				
				foreach ($results as $form_result){
					if ($form_result->type == 'form'){
						$out .= '<div><input type="hidden" name="'.$formname.'_email" id="'.$formname.'_wemail" value="'.$email_adress_reciever.'" /></div>'.
						'<div><input type="hidden" name="'.$formname.'_url" id="'.$formname.'_wurl" value="'.get_template_directory_uri().'/theme/functions/form_builder_sendmail.php" /></div>'.
						'<div class="cl"></div>'.
						'<div class="loading"></div>'.
						'<div class="fl"><a id="'.$formname.'_wformsend" class="but_styled" href="#"><span><span class="check">'.__('Submit', 'clockstone').'</span></span></a></div>';
						
						if (str_replace('reset', '', $form_result->parameters) != $form_result->parameters) $out .= '<div class="fl" style="padding:0 0 0 20px;"><a id="'.$formname.'_wformclear" class="but_small_trans" href="#" onclick="javascript:document.getElementById(\'form_'.$formname.'\').reset(); return false;"><span>'.__('Reset', 'clockstone').'</span></a></div>';
						
						$out .= '<div class="cl"></div>'.
								'</form>'.
							'</div>'.
						'</div>';
					}
				}
				
				echo $out;
			}
			
		echo $after_widget;
		
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_contact_form', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['email'] = strip_tags($new_instance['email']);
		$instance['formname'] = $new_instance['formname'];
		$instance['widget_width'] = $new_instance['widget_width'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_contact_form_entries']) )
			delete_option('widget_custom_contact_form_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_contact_form', 'widget');
	}

	function form( $instance ) {
		global $wpdb, $shortname;
		
		$get_forms = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix.$shortname."_forms WHERE type='form'");
		
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$email = isset($instance['email']) ? esc_attr($instance['email']) : '';
		if ( !isset($instance['formname']) || !$formname = $instance['formname'] )
			$formname = '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('email'); ?>"><?php _e('Email Address:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('email'); ?>" name="<?php echo $this->get_field_name('email'); ?>" type="text" value="<?php echo $email; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('formname'); ?>"><?php _e('Form Name:<br />'); ?>
		<select id="<?php echo $this->get_field_id('formname'); ?>" name="<?php echo $this->get_field_name('formname'); ?>" style="width:225px;">
			<option value="">Choose Form Name Here &nbsp;</option>
		<?php foreach ($get_forms as $get_form){
			$val = $get_form->slug;
			$name = $get_form->label;
			
			if ($formname == $val){
				$selected = ' selected="selected"';
			} else {
				$selected = '';
			}
			
			echo '<option'.$selected.' value="'.$val.'">'.$name.'</option>';
		} ?>
		</select>
		</label></p>
		
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}


/**
 * Advertisement Widget Class
 */
class WP_Widget_Custom_Advertisement extends WP_Widget {
	
	function WP_Widget_Custom_Advertisement() {
		$widget_ops = array('classname' => 'widget_custom_advertisement_entries', 'description' => __( "Your Advertisement") );
		$this->WP_Widget('custom-advertisement', __('&nbsp;CMSMS - Advertisement'), $widget_ops);
		$this->alt_option_name = 'widget_custom_advertisement_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_advertisement', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Advertisement') : $instance['title'], $instance, $this->id_base);
		$image1 = apply_filters('widget_title', empty($instance['image1']) ? __('') : $instance['image1'], $instance, $this->id_base);
		$link1 = apply_filters('widget_title', empty($instance['link1']) ? __('') : $instance['link1'], $instance, $this->id_base);
		$image2 = apply_filters('widget_title', empty($instance['image2']) ? __('') : $instance['image2'], $instance, $this->id_base);
		$link2 = apply_filters('widget_title', empty($instance['link2']) ? __('') : $instance['link2'], $instance, $this->id_base);
		$image3 = apply_filters('widget_title', empty($instance['image3']) ? __('') : $instance['image3'], $instance, $this->id_base);
		$link3 = apply_filters('widget_title', empty($instance['link3']) ? __('') : $instance['link3'], $instance, $this->id_base);
		$image4 = apply_filters('widget_title', empty($instance['image4']) ? __('') : $instance['image4'], $instance, $this->id_base);
		$link4 = apply_filters('widget_title', empty($instance['link4']) ? __('') : $instance['link4'], $instance, $this->id_base);
		$image5 = apply_filters('widget_title', empty($instance['image5']) ? __('') : $instance['image5'], $instance, $this->id_base);
		$link5 = apply_filters('widget_title', empty($instance['link5']) ? __('') : $instance['link5'], $instance, $this->id_base);
		$image6 = apply_filters('widget_title', empty($instance['image6']) ? __('') : $instance['image6'], $instance, $this->id_base);
		$link6 = apply_filters('widget_title', empty($instance['link6']) ? __('') : $instance['link6'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
			if ( $title ) echo $before_title . $title . $after_title;
			
			if ($image1 != '' && $link1 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link1.'"><img src="'.$image1.'" alt="" /></a></span>';
			}
			
			if ($image2 != '' && $link2 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link2.'"><img src="'.$image2.'" alt="" /></a></span>';
			}
			
			if ($image3 != '' && $link3 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link3.'"><img src="'.$image3.'" alt="" /></a></span>';
			}
			
			if ($image4 != '' && $link4 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link4.'"><img src="'.$image4.'" alt="" /></a></span>';
			}
			
			if ($image5 != '' && $link5 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link5.'"><img src="'.$image5.'" alt="" /></a></span>';
			}
			
			if ($image6 != '' && $link6 != ''){
				echo '<span class="adv_widget_image"><a href="'.$link6.'"><img src="'.$image6.'" alt="" /></a></span>';
			}
		echo '</div>';
		echo $after_widget;
			
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_advertisement', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['image1'] = strip_tags($new_instance['image1']);
		$instance['link1'] = strip_tags($new_instance['link1']);
		$instance['image2'] = strip_tags($new_instance['image2']);
		$instance['link2'] = strip_tags($new_instance['link2']);
		$instance['image3'] = strip_tags($new_instance['image3']);
		$instance['link3'] = strip_tags($new_instance['link3']);
		$instance['image4'] = strip_tags($new_instance['image4']);
		$instance['link4'] = strip_tags($new_instance['link4']);
		$instance['image5'] = strip_tags($new_instance['image5']);
		$instance['link5'] = strip_tags($new_instance['link5']);
		$instance['image6'] = strip_tags($new_instance['image6']);
		$instance['link6'] = strip_tags($new_instance['link6']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_advertisement_entries']) )
			delete_option('widget_custom_advertisement_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_advertisement', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$image1 = isset($instance['image1']) ? esc_attr($instance['image1']) : '';
		$link1 = isset($instance['link1']) ? esc_attr($instance['link1']) : '';
		$image2 = isset($instance['image2']) ? esc_attr($instance['image2']) : '';
		$link2 = isset($instance['link2']) ? esc_attr($instance['link2']) : '';
		$image3 = isset($instance['image3']) ? esc_attr($instance['image3']) : '';
		$link3 = isset($instance['link3']) ? esc_attr($instance['link3']) : '';
		$image4 = isset($instance['image4']) ? esc_attr($instance['image4']) : '';
		$link4 = isset($instance['link4']) ? esc_attr($instance['link4']) : '';
		$image5 = isset($instance['image5']) ? esc_attr($instance['image5']) : '';
		$link5 = isset($instance['link5']) ? esc_attr($instance['link5']) : '';
		$image6 = isset($instance['image6']) ? esc_attr($instance['image6']) : '';
		$link6 = isset($instance['link6']) ? esc_attr($instance['link6']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image1'); ?>"><?php _e('Image #1:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image1'); ?>" name="<?php echo $this->get_field_name('image1'); ?>" type="text" value="<?php echo $image1; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link1'); ?>"><?php _e('Link #1:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link1'); ?>" name="<?php echo $this->get_field_name('link1'); ?>" type="text" value="<?php echo $link1; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image2'); ?>"><?php _e('Image #2:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image2'); ?>" name="<?php echo $this->get_field_name('image2'); ?>" type="text" value="<?php echo $image2; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link2'); ?>"><?php _e('Link #2:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link2'); ?>" name="<?php echo $this->get_field_name('link2'); ?>" type="text" value="<?php echo $link2; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image3'); ?>"><?php _e('Image #3:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image3'); ?>" name="<?php echo $this->get_field_name('image3'); ?>" type="text" value="<?php echo $image3; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link3'); ?>"><?php _e('Link #3:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link3'); ?>" name="<?php echo $this->get_field_name('link3'); ?>" type="text" value="<?php echo $link3; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image4'); ?>"><?php _e('Image #4:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image4'); ?>" name="<?php echo $this->get_field_name('image4'); ?>" type="text" value="<?php echo $image4; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link4'); ?>"><?php _e('Link #4:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link4'); ?>" name="<?php echo $this->get_field_name('link4'); ?>" type="text" value="<?php echo $link4; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image5'); ?>"><?php _e('Image #5:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image5'); ?>" name="<?php echo $this->get_field_name('image5'); ?>" type="text" value="<?php echo $image5; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link5'); ?>"><?php _e('Link #5:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link5'); ?>" name="<?php echo $this->get_field_name('link5'); ?>" type="text" value="<?php echo $link5; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('image6'); ?>"><?php _e('Image #6:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('image6'); ?>" name="<?php echo $this->get_field_name('image6'); ?>" type="text" value="<?php echo $image6; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('link6'); ?>"><?php _e('Link #6:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('link6'); ?>" name="<?php echo $this->get_field_name('link6'); ?>" type="text" value="<?php echo $link6; ?>" /></label></p>
		
		<p>Image must be 125x125 pixels!</p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>

<?php
	}
}


/**
 * Video Widget Class
 */
class WP_Widget_Custom_Video extends WP_Widget {
	
	function WP_Widget_Custom_Video() {
		$widget_ops = array('classname' => 'widget_custom_video_entries', 'description' => __( "Your Video") );
		$this->WP_Widget('custom-video', __('&nbsp;CMSMS - Embeded Video'), $widget_ops);
		$this->alt_option_name = 'widget_custom_video_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_video', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Video') : $instance['title'], $instance, $this->id_base);
		$url = apply_filters('widget_title', empty($instance['url']) ? __('') : $instance['url'], $instance, $this->id_base);
		$width = apply_filters('widget_title', empty($instance['width']) ? __('280') : $instance['width'], $instance, $this->id_base);
		$height = apply_filters('widget_title', empty($instance['height']) ? __('160') : $instance['height'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
			
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
			if ( $title ) echo $before_title . $title . $after_title;
			
			if ($url != ''){
				echo get_video_iframe($url, $width, $height);
			}
		echo '</div>';	
		echo $after_widget;
			
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_video', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['url'] = strip_tags($new_instance['url']);
		$instance['width'] = strip_tags($new_instance['width']);
		$instance['height'] = strip_tags($new_instance['height']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_video_entries']) )
			delete_option('widget_custom_video_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_video', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$url = isset($instance['url']) ? esc_attr($instance['url']) : '';
		$width = isset($instance['width']) ? esc_attr($instance['width']) : '';
		$height = isset($instance['height']) ? esc_attr($instance['height']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('url'); ?>"><?php _e('Video URL:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('url'); ?>" name="<?php echo $this->get_field_name('url'); ?>" type="text" value="<?php echo $url; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Video Width:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>" type="text" value="<?php echo $width; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('height'); ?>"><?php _e('Video Height:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('height'); ?>" name="<?php echo $this->get_field_name('height'); ?>" type="text" value="<?php echo $height; ?>" /></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>

<?php
	}
}


/**
 * HTML5 Video Widget Class
 */
class WP_Widget_Custom_HTML5_Video extends WP_Widget {
	
	function WP_Widget_Custom_HTML5_Video() {
		$widget_ops = array('classname' => 'widget_custom_html5_video_entries', 'description' => __( "Your HTML5 Video") );
		$this->WP_Widget('custom-html5-video', __('&nbsp;CMSMS - HTML5 Video'), $widget_ops);
		$this->alt_option_name = 'widget_custom_html5_video_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_html5_video', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('HTML5 Video') : $instance['title'], $instance, $this->id_base);
		$srcogg = apply_filters('widget_title', empty($instance['srcogg']) ? __('') : $instance['srcogg'], $instance, $this->id_base);
		$srcmp4 = apply_filters('widget_title', empty($instance['srcmp4']) ? __('') : $instance['srcmp4'], $instance, $this->id_base);
		$srcwebm = apply_filters('widget_title', empty($instance['srcwebm']) ? __('') : $instance['srcwebm'], $instance, $this->id_base);
		$poster = apply_filters('widget_title', empty($instance['poster']) ? __('') : $instance['poster'], $instance, $this->id_base);
		$text = apply_filters('widget_title', empty($instance['text']) ? __('Your browser does not support the video tag.') : $instance['text'], $instance, $this->id_base);
		$width = apply_filters('widget_title', empty($instance['width']) ? __('267') : $instance['width'], $instance, $this->id_base);
		$height = apply_filters('widget_title', empty($instance['height']) ? __('153') : $instance['height'], $instance, $this->id_base);
		$controls = apply_filters('widget_title', empty($instance['controls']) ? __('controls') : $instance['controls'], $instance, $this->id_base);
		$autoplay = apply_filters('widget_title', empty($instance['autoplay']) ? __('') : $instance['autoplay'], $instance, $this->id_base);
		$audio = apply_filters('widget_title', empty($instance['audio']) ? __('') : $instance['audio'], $instance, $this->id_base);
		$loop = apply_filters('widget_title', empty($instance['loop']) ? __('') : $instance['loop'], $instance, $this->id_base);
		$preload = apply_filters('widget_title', empty($instance['preload']) ? __('') : $instance['preload'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
			
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
			if ( $title ) echo $before_title . $title . $after_title;
			
			$out .= '<video width="'.$width.'" height="'.$height.'"';
			
			if ( $poster != '' ) {
				$out .= ' poster="'.$poster.'"';
			}

			if ( $controls != '' ) {
				$out .= ' controls="controls"';
			}
			
			if ( $autoplay != '' ) {
				$out .= ' autoplay="autoplay"';
			}

			if ( $audio != '' ) {
				$out .= ' audio="muted"';
			}

			if ( $loop != '' ) {
				$out .= ' loop="loop"';
			}

			if ( $preload != '' ) {
				$out .= ' preload="preload"';
			}
			
			$out .= '>';

			if ( $srcogg != '' ) {
				$out .= '<source src="'.$srcogg.'" type="video/ogg" />';
			}

			if ( $srcmp4 != '' ) {
				$out .= '<source src="'.$srcmp4.'" type="video/mp4" />';
			}

			if ( $srcwebm != '' ) {
				$out .= '<source src="'.$srcwebm.'" type="video/webm" />';
			}

			$out .= $text;

			$out .= '</video>';
			
			echo $out;
		echo '</div>';
		echo $after_widget;
			
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_html5_video', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['srcogg'] = strip_tags($new_instance['srcogg']);
		$instance['srcmp4'] = strip_tags($new_instance['srcmp4']);
		$instance['srcwebm'] = strip_tags($new_instance['srcwebm']);
		$instance['poster'] = strip_tags($new_instance['poster']);
		$instance['text'] = strip_tags($new_instance['text']);
		$instance['width'] = strip_tags($new_instance['width']);
		$instance['height'] = strip_tags($new_instance['height']);
		$instance['controls'] = strip_tags($new_instance['controls']);
		$instance['autoplay'] = strip_tags($new_instance['autoplay']);
		$instance['audio'] = strip_tags($new_instance['audio']);
		$instance['loop'] = strip_tags($new_instance['loop']);
		$instance['preload'] = strip_tags($new_instance['preload']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_html5_video_entries']) )
			delete_option('widget_custom_html5_video_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_html5_video', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$srcogg = isset($instance['srcogg']) ? esc_attr($instance['srcogg']) : '';
		$srcmp4 = isset($instance['srcmp4']) ? esc_attr($instance['srcmp4']) : '';
		$srcwebm = isset($instance['srcwebm']) ? esc_attr($instance['srcwebm']) : '';
		$poster = isset($instance['poster']) ? esc_attr($instance['poster']) : '';
		$text = isset($instance['text']) ? esc_attr($instance['text']) : '';
		$width = isset($instance['width']) ? esc_attr($instance['width']) : '';
		$height = isset($instance['height']) ? esc_attr($instance['height']) : '';
		$controls = isset($instance['controls']) ? esc_attr($instance['controls']) : '';
		$autoplay = isset($instance['autoplay']) ? esc_attr($instance['autoplay']) : '';
		$audio = isset($instance['audio']) ? esc_attr($instance['audio']) : '';
		$loop = isset($instance['loop']) ? esc_attr($instance['loop']) : '';
		$preload = isset($instance['preload']) ? esc_attr($instance['preload']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('srcmp4'); ?>"><?php _e('Video .mp4 File Format Source:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('srcmp4'); ?>" name="<?php echo $this->get_field_name('srcmp4'); ?>" type="text" value="<?php echo $srcmp4; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('srcogg'); ?>"><?php _e('Video .ogg File Format Source:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('srcogg'); ?>" name="<?php echo $this->get_field_name('srcogg'); ?>" type="text" value="<?php echo $srcogg; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('srcwebm'); ?>"><?php _e('Video .webm File Format Source:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('srcwebm'); ?>" name="<?php echo $this->get_field_name('srcwebm'); ?>" type="text" value="<?php echo $srcwebm; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('poster'); ?>"><?php _e('Poster Source:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('poster'); ?>" name="<?php echo $this->get_field_name('poster'); ?>" type="text" value="<?php echo $poster; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('text'); ?>"><?php _e('Video Tag Not Support Text:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>" type="text" value="<?php echo $text; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Video Width:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>" type="text" value="<?php echo $width; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('height'); ?>"><?php _e('Video Height:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('height'); ?>" name="<?php echo $this->get_field_name('height'); ?>" type="text" value="<?php echo $height; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('controls'); ?>"><?php _e('Controls:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('controls'); ?>" name="<?php echo $this->get_field_name('controls'); ?>"><option value="controls" <?php if($controls=='controls'){ echo ' selected="selected"'; } ?>>Enable Controls</option><option value="" <?php if($controls==''){ echo ' selected="selected"'; } ?>>Disable Controls</option></select></label></p>
		
		<p><label for="<?php echo $this->get_field_id('autoplay'); ?>"><?php _e('Autoplay:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('autoplay'); ?>" name="<?php echo $this->get_field_name('autoplay'); ?>"><option value="" <?php if($autoplay==''){ echo ' selected="selected"'; } ?>>Disable Autoplay</option><option value="autoplay" <?php if($autoplay=='autoplay'){ echo ' selected="selected"'; } ?>>Enable Autoplay</option></select></label></p>
		
		<p><label for="<?php echo $this->get_field_id('audio'); ?>"><?php _e('Audio:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('audio'); ?>" name="<?php echo $this->get_field_name('audio'); ?>"><option value="" <?php if($audio==''){ echo ' selected="selected"'; } ?>>Enable Audio</option><option value="muted" <?php if($audio=='muted'){ echo ' selected="selected"'; } ?>>Disable Audio</option></select></label></p>
		
		<p><label for="<?php echo $this->get_field_id('loop'); ?>"><?php _e('Loop:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('loop'); ?>" name="<?php echo $this->get_field_name('loop'); ?>"><option value="" <?php if($loop==''){ echo ' selected="selected"'; } ?>>Disable Loop</option><option value="loop" <?php if($loop=='loop'){ echo ' selected="selected"'; } ?>>Enable Loop</option></select></label></p>

		<p><label for="<?php echo $this->get_field_id('preload'); ?>"><?php _e('Preload:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('preload'); ?>" name="<?php echo $this->get_field_name('preload'); ?>"><option value="" <?php if($preload==''){ echo ' selected="selected"'; } ?>>Disable Preload</option><option value="preload" <?php if($preload=='preload'){ echo ' selected="selected"'; } ?>>Enable Preload</option></select></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * HTML5 Audio Widget Class
 */
class WP_Widget_Custom_HTML5_Audio extends WP_Widget {
	
	function WP_Widget_Custom_HTML5_Audio() {
		$widget_ops = array('classname' => 'widget_custom_html5_audio_entries', 'description' => __( "Your HTML5 Audio") );
		$this->WP_Widget('custom-html5-audio', __('&nbsp;CMSMS - HTML5 Audio'), $widget_ops);
		$this->alt_option_name = 'widget_custom_html5_audio_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_html5_audio', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('HTML5 Audio') : $instance['title'], $instance, $this->id_base);
		$src = apply_filters('widget_title', empty($instance['src']) ? __('') : $instance['src'], $instance, $this->id_base);
		$text = apply_filters('widget_title', empty($instance['text']) ? __('Your browser does not support the audio tag.') : $instance['text'], $instance, $this->id_base);
		$controls = apply_filters('widget_title', empty($instance['controls']) ? __('controls') : $instance['controls'], $instance, $this->id_base);
		$autoplay = apply_filters('widget_title', empty($instance['autoplay']) ? __('') : $instance['autoplay'], $instance, $this->id_base);
		$loop = apply_filters('widget_title', empty($instance['loop']) ? __('') : $instance['loop'], $instance, $this->id_base);
		$preload = apply_filters('widget_title', empty($instance['preload']) ? __('none') : $instance['preload'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
			
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
			if ( $title ) echo $before_title . $title . $after_title;
			
			$out .= '<audio src="'.$src.'"';
			
			if ( $controls != '' ) {
				$out .= ' controls="controls"';
			}
			
			if ( $autoplay != '' ) {
				$out .= ' autoplay="autoplay"';
			}

			if ( $loop != '' ) {
				$out .= ' loop="loop"';
			}

			if ( $preload != '' ) {
				$out .= ' preload="'.$preload.'"';
			}
			
			$out .= '>';

			$out .= $text;

			$out .= '</audio>';
			
			echo $out;
		echo '</div>';
		echo $after_widget;
			
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_html5_audio', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['src'] = strip_tags($new_instance['src']);
		$instance['text'] = strip_tags($new_instance['text']);
		$instance['controls'] = strip_tags($new_instance['controls']);
		$instance['autoplay'] = strip_tags($new_instance['autoplay']);
		$instance['loop'] = strip_tags($new_instance['loop']);
		$instance['preload'] = strip_tags($new_instance['preload']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_html5_audio_entries']) )
			delete_option('widget_custom_html5_audio_entries');
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_html5_audio', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$src = isset($instance['src']) ? esc_attr($instance['src']) : '';
		$text = isset($instance['text']) ? esc_attr($instance['text']) : '';
		$controls = isset($instance['controls']) ? esc_attr($instance['controls']) : '';
		$autoplay = isset($instance['autoplay']) ? esc_attr($instance['autoplay']) : '';
		$loop = isset($instance['loop']) ? esc_attr($instance['loop']) : '';
		$preload = isset($instance['preload']) ? esc_attr($instance['preload']) : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>
		
		<p><label for="<?php echo $this->get_field_id('src'); ?>"><?php _e('Audio Source:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('src'); ?>" name="<?php echo $this->get_field_name('src'); ?>" type="text" value="<?php echo $src; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('text'); ?>"><?php _e('Audio Tag Not Support Text:<br />'); ?>
		<input class="widefat" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>" type="text" value="<?php echo $text; ?>" /></label></p>

		<p><label for="<?php echo $this->get_field_id('controls'); ?>"><?php _e('Controls:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('controls'); ?>" name="<?php echo $this->get_field_name('controls'); ?>"><option value="controls" <?php if($controls=='controls'){ echo ' selected="selected"'; } ?>>Enable Controls</option><option value="" <?php if($controls==''){ echo ' selected="selected"'; } ?>>Disable Controls</option></select></label></p>
		
		<p><label for="<?php echo $this->get_field_id('autoplay'); ?>"><?php _e('Autoplay:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('autoplay'); ?>" name="<?php echo $this->get_field_name('autoplay'); ?>"><option value="" <?php if($autoplay==''){ echo ' selected="selected"'; } ?>>Disable Autoplay</option><option value="autoplay" <?php if($autoplay=='autoplay'){ echo ' selected="selected"'; } ?>>Enable Autoplay</option></select></label></p>
		
		<p><label for="<?php echo $this->get_field_id('loop'); ?>"><?php _e('Loop:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('loop'); ?>" name="<?php echo $this->get_field_name('loop'); ?>"><option value="" <?php if($loop==''){ echo ' selected="selected"'; } ?>>Disable Loop</option><option value="loop" <?php if($loop=='loop'){ echo ' selected="selected"'; } ?>>Enable Loop</option></select></label></p>

		<p><label for="<?php echo $this->get_field_id('preload'); ?>"><?php _e('Preload:<br />'); ?>
		<select class="widefat" id="<?php echo $this->get_field_id('preload'); ?>" name="<?php echo $this->get_field_name('preload'); ?>"><option value="none" <?php if($preload=='none'){ echo ' selected="selected"'; } ?>>None</option><option value="metadata" <?php if($preload=='metadata'){ echo ' selected="selected"'; } ?>>Metadata</option><option value="auto" <?php if($preload=='auto'){ echo ' selected="selected"'; } ?>>Auto</option></select></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}



/**
 * Divider Widget Class
 */
class WP_Widget_Custom_Divider extends WP_Widget {
	
	function WP_Widget_Custom_Divider() {
		$widget_ops = array('classname' => 'widget_custom_divider_entries', 'description' => __( "Divider for widgets rows") );
		$this->WP_Widget('custom-divider', __('&nbsp;CMSMS - Divider'), $widget_ops);
		$this->alt_option_name = 'widget_custom_divider_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_custom_divider', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		if ( !$divider_type = $instance['divider_type'] )
			$divider_type = '';
		if ( !$divider_text = $instance['divider_text'] )
			$divider_text = 'Top';

?>
		<?php 
			if ($divider_type == 'line_top'){
				echo '<div class="divider"><a href="#">'.$divider_text.' &uarr;</a></div>';				
			} else if ($divider_type == 'line'){
				echo '<div class="divider"></div>';
			} else {
				echo '<div class="cl"></div>';
			}
		?>
<?php

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_custom_divider', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['divider_type'] = $new_instance['divider_type'];
		$instance['divider_text'] = $new_instance['divider_text'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_custom_divider']) )
			delete_option('widget_custom_divider');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_custom_divider', 'widget');
	}

	function form( $instance ) {
		if ( !isset($instance['divider_type']) || !$divider_type = $instance['divider_type'] )
			$divider_type = '';
		if ( !isset($instance['divider_text']) || !$divider_text = $instance['divider_text'] )
			$divider_text = 'Top';
?>
	
		<p><label for="<?php echo $this->get_field_id('divider_type'); ?>"><?php _e('Choose your divider type:<br /><br />'); ?>
		<select id="<?php echo $this->get_field_id('divider_type'); ?>" name="<?php echo $this->get_field_name('divider_type'); ?>">
			<option <?php if ($divider_type == ''){ echo ' selected="selected"'; } ?>value="">Divider without line</option>
			<option <?php if ($divider_type == 'line'){ echo ' selected="selected"'; } ?>value="line">Divider with Line</option>
			<option <?php if ($divider_type == 'line_top'){ echo ' selected="selected"'; } ?>value="line_top">Divider with line &amp; link&nbsp;</option>
		</select>
		</label><br /></p>

		<p><label for="<?php echo $this->get_field_id('divider_text'); ?>"><?php _e('Enter the text of divider line text you\'d like to display:<br /><br />'); ?>
		<input id="<?php echo $this->get_field_id('divider_text'); ?>" name="<?php echo $this->get_field_name('divider_text'); ?>" type="text" value="<?php echo $divider_text; ?>" size="15" /><small style="color:#f00; float:right; padding-top:2px;">default is 'Top'</small></label></p>

<?php
	}
}





/**
 * Pages widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Pages_Custom extends WP_Widget {

	function WP_Widget_Pages_Custom() {
		$widget_ops = array('classname' => 'widget_pages', 'description' => __( 'Your site&#8217;s WordPress Pages') );
		$this->WP_Widget('pages', __('Pages'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __( 'Pages' ) : $instance['title'], $instance, $this->id_base);
		$sortby = empty( $instance['sortby'] ) ? 'menu_order' : $instance['sortby'];
		$exclude = empty( $instance['exclude'] ) ? '' : $instance['exclude'];
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';

		if ( $sortby == 'menu_order' )
			$sortby = 'menu_order, post_title';

		$out = wp_list_pages( apply_filters('widget_pages_args', array('title_li' => '', 'echo' => 0, 'sort_column' => $sortby, 'exclude' => $exclude) ) );

		if ( !empty( $out ) ) {
			echo $before_widget;
		?> <div class="<?php echo $widget_width; ?>"> <?php
			if ( $title)
				echo $before_title . $title . $after_title;
		?>
		<ul>
			<?php echo $out; ?>
		</ul>
		</div>
		<?php
			echo $after_widget;
		}
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( in_array( $new_instance['sortby'], array( 'post_title', 'menu_order', 'ID' ) ) ) {
			$instance['sortby'] = $new_instance['sortby'];
		} else {
			$instance['sortby'] = 'menu_order';
		}

		$instance['exclude'] = strip_tags( $new_instance['exclude'] );
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'sortby' => 'post_title', 'title' => '', 'exclude' => '') );
		$title = esc_attr( $instance['title'] );
		$exclude = esc_attr( $instance['exclude'] );
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
	?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('sortby'); ?>"><?php _e( 'Sort by:' ); ?></label>
			<select name="<?php echo $this->get_field_name('sortby'); ?>" id="<?php echo $this->get_field_id('sortby'); ?>" class="widefat">
				<option value="post_title"<?php selected( $instance['sortby'], 'post_title' ); ?>><?php _e('Page title'); ?></option>
				<option value="menu_order"<?php selected( $instance['sortby'], 'menu_order' ); ?>><?php _e('Page order'); ?></option>
				<option value="ID"<?php selected( $instance['sortby'], 'ID' ); ?>><?php _e( 'Page ID' ); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('exclude'); ?>"><?php _e( 'Exclude:' ); ?></label> <input type="text" value="<?php echo $exclude; ?>" name="<?php echo $this->get_field_name('exclude'); ?>" id="<?php echo $this->get_field_id('exclude'); ?>" class="widefat" />
			<br />
			<small><?php _e( 'Page IDs, separated by commas.' ); ?></small>
		</p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}

}



/**
 * Links widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Links_Custom extends WP_Widget {

	function WP_Widget_Links_Custom() {
		$widget_ops = array('description' => __( "Your blogroll" ) );
		$this->WP_Widget('links', __('Links'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args, EXTR_SKIP);

		$show_description = isset($instance['description']) ? $instance['description'] : false;
		$show_name = isset($instance['name']) ? $instance['name'] : false;
		$show_rating = isset($instance['rating']) ? $instance['rating'] : false;
		$show_images = isset($instance['images']) ? $instance['images'] : true;
		$category = isset($instance['category']) ? $instance['category'] : false;

		if ( is_admin() && !$category ) {
			// Display All Links widget as such in the widgets screen
			echo $before_widget . $before_title. __('All Links') . $after_title . $after_widget;
			return;
		}
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		$before_widget = preg_replace('/id="[^"]*"/','id="%id"', $before_widget);
		wp_list_bookmarks(array( 'category_before' => '<div class="widget widget_links"> <div class="'.$widget_width.'">', 'title_before' => '<h3 class="widgettitle">', 'title_after' => '</h3>', 'category_after' => '</div> </div>', 'show_images' => $show_images, 'show_description' => $show_description, 'show_name' => $show_name, 'show_rating' => $show_rating, 'category' => $category));
	}
		
	function update( $new_instance, $old_instance ) {
		$new_instance = (array) $new_instance;
		$instance = array( 'images' => 0, 'name' => 0, 'description' => 0, 'rating' => 0);
		foreach ( $instance as $field => $val ) {
			if ( isset($new_instance[$field]) )
				$instance[$field] = 1;
		}
		$instance['category'] = intval($new_instance['category']);
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {

		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'images' => true, 'name' => true, 'description' => false, 'rating' => false, 'category' => false ) );
		$link_cats = get_terms( 'link_category');
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p>
		<label for="<?php echo $this->get_field_id('category'); ?>" class="screen-reader-text"><?php _e('Select Link Category'); ?></label>
		<select class="widefat" id="<?php echo $this->get_field_id('category'); ?>" name="<?php echo $this->get_field_name('category'); ?>">
		<option value=""><?php _e('All Links'); ?></option>
		<?php
		foreach ( $link_cats as $link_cat ) {
			echo '<option value="' . intval($link_cat->term_id) . '"'
				. ( $link_cat->term_id == $instance['category'] ? ' selected="selected"' : '' )
				. '>' . $link_cat->name . "</option>\n";
		}
		?>
		</select></p>
		<p>
		<input class="checkbox" type="checkbox" <?php checked($instance['images'], true) ?> id="<?php echo $this->get_field_id('images'); ?>" name="<?php echo $this->get_field_name('images'); ?>" />
		<label for="<?php echo $this->get_field_id('images'); ?>"><?php _e('Show Link Image'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['name'], true) ?> id="<?php echo $this->get_field_id('name'); ?>" name="<?php echo $this->get_field_name('name'); ?>" />
		<label for="<?php echo $this->get_field_id('name'); ?>"><?php _e('Show Link Name'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['description'], true) ?> id="<?php echo $this->get_field_id('description'); ?>" name="<?php echo $this->get_field_name('description'); ?>" />
		<label for="<?php echo $this->get_field_id('description'); ?>"><?php _e('Show Link Description'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['rating'], true) ?> id="<?php echo $this->get_field_id('rating'); ?>" name="<?php echo $this->get_field_name('rating'); ?>" />
		<label for="<?php echo $this->get_field_id('rating'); ?>"><?php _e('Show Link Rating'); ?></label>
		</p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}

/**
 * Search widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Search_Custom extends WP_Widget {

	function WP_Widget_Search_Custom() {
		$widget_ops = array('classname' => 'widget_search', 'description' => __( "A search form for your site") );
		$this->WP_Widget('search', __('Search'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
			
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;

		// Use current theme search form if it exists
		get_search_form();
		
		echo '</div>';
		echo $after_widget;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '') );
		$title = $instance['title'];
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$new_instance = wp_parse_args((array) $new_instance, array( 'title' => ''));
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['widget_width'] = $new_instance['widget_width'];
		return $instance;
	}

}

/**
 * Archives widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Archives_Custom extends WP_Widget {

	function WP_Widget_Archives_Custom() {
		$widget_ops = array('classname' => 'widget_archive', 'description' => __( 'A monthly archive of your site&#8217;s posts') );
		$this->WP_Widget('archives', __('Archives'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$c = $instance['count'] ? '1' : '0';
		$d = $instance['dropdown'] ? '1' : '0';
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Archives') : $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;

		if ( $d ) {
?>
		<select name="archive-dropdown" onchange='document.location.href=this.options[this.selectedIndex].value;'> <option value=""><?php echo esc_attr(__('Select Month')); ?></option> <?php wp_get_archives(apply_filters('widget_archives_dropdown_args', array('type' => 'monthly', 'format' => 'option', 'show_post_count' => $c))); ?> </select>
<?php
		} else {
?>
		<ul>
		<?php wp_get_archives(apply_filters('widget_archives_args', array('type' => 'monthly', 'show_post_count' => $c))); ?>
		</ul>
<?php
		}

		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$new_instance = wp_parse_args( (array) $new_instance, array( 'title' => '', 'count' => 0, 'dropdown' => '') );
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['count'] = $new_instance['count'] ? 1 : 0;
		$instance['dropdown'] = $new_instance['dropdown'] ? 1 : 0;
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'count' => 0, 'dropdown' => '') );
		$title = strip_tags($instance['title']);
		$count = $instance['count'] ? 'checked="checked"' : '';
		$dropdown = $instance['dropdown'] ? 'checked="checked"' : '';
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $dropdown; ?> id="<?php echo $this->get_field_id('dropdown'); ?>" name="<?php echo $this->get_field_name('dropdown'); ?>" /> <label for="<?php echo $this->get_field_id('dropdown'); ?>"><?php _e('Display as dropdown'); ?></label>
			<br/>
			<input class="checkbox" type="checkbox" <?php echo $count; ?> id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" /> <label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Show post counts'); ?></label>
		</p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}

/**
 * Meta widget class
 *
 * Displays log in/out, RSS feed links, etc.
 *
 * @since 2.8.0
 */
class WP_Widget_Meta_Custom extends WP_Widget {

	function WP_Widget_Meta_Custom() {
		$widget_ops = array('classname' => 'widget_meta', 'description' => __( "Log in/out, admin, feed and links") );
		$this->WP_Widget('meta', __('Meta'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Meta') : $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;
?>
			<ul>
			<?php wp_register(); ?>
			<li><?php wp_loginout(); ?></li>
			<li><a href="<?php bloginfo('rss2_url'); ?>" title="<?php echo esc_attr(__('Syndicate this site using RSS 2.0')); ?>"><?php _e('Entries <abbr title="Really Simple Syndication">RSS</abbr>'); ?></a></li>
			<li><a href="<?php bloginfo('comments_rss2_url'); ?>" title="<?php echo esc_attr(__('The latest comments to all posts in RSS')); ?>"><?php _e('Comments <abbr title="Really Simple Syndication">RSS</abbr>'); ?></a></li>
			<li><a href="http://wordpress.org/" title="<?php echo esc_attr(__('Powered by WordPress, state-of-the-art semantic personal publishing platform.')); ?>">WordPress.org</a></li>
			<?php wp_meta(); ?>
			</ul>
<?php
		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = strip_tags($instance['title']);
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
			<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
			<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
			<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
			<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
				<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
				<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
				<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
				<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
				<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
				<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
				<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
				<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
				<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
				<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
			</select>
			</label></p>
			<div style="clear:both;"></div>
<?php
	}
}

/**
 * Calendar widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Calendar_Custom extends WP_Widget {

	function WP_Widget_Calendar_Custom() {
		$widget_ops = array('classname' => 'widget_calendar', 'description' => __( 'A calendar of your site&#8217;s posts') );
		$this->WP_Widget('calendar', __('Calendar'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters('widget_title', empty($instance['title']) ? '&nbsp;' : $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;
		echo '<div id="calendar_wrap">';
		get_calendar();
		echo '</div>';
		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = strip_tags($instance['title']);
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}

/**
 * Text widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Text_Custom extends WP_Widget {

	function WP_Widget_Text_Custom() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('Arbitrary text or HTML'));
		$control_ops = array('width' => 400, 'height' => 350);
		$this->WP_Widget('text', __('Text'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters( 'widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$text = apply_filters( 'widget_text', $instance['text'], $instance );
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
			<div class="textwidget"><?php echo $instance['filter'] ? wpautop($text) : $text; ?></div>
		<?php
		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		$instance['widget_width'] = $new_instance['widget_width'];
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '' ) );
		$title = strip_tags($instance['title']);
		$text = esc_textarea($instance['text']);
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>

		<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs'); ?></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}
}

/**
 * Categories widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Categories_Custom extends WP_Widget {

	function WP_Widget_Categories_Custom() {
		$widget_ops = array( 'classname' => 'widget_categories', 'description' => __( "A list or dropdown of categories" ) );
		$this->WP_Widget('categories', __('Categories'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __( 'Categories' ) : $instance['title'], $instance, $this->id_base);
		$c = $instance['count'] ? '1' : '0';
		$h = $instance['hierarchical'] ? '1' : '0';
		$d = $instance['dropdown'] ? '1' : '0';
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;

		$cat_args = array('orderby' => 'name', 'show_count' => $c, 'hierarchical' => $h);

		if ( $d ) {
			$cat_args['show_option_none'] = __('Select Category');
			wp_dropdown_categories(apply_filters('widget_categories_dropdown_args', $cat_args));
?>

<script type='text/javascript'>
/* <![CDATA[ */
	var dropdown = document.getElementById("cat");
	function onCatChange() {
		if ( dropdown.options[dropdown.selectedIndex].value > 0 ) {
			location.href = "<?php echo home_url(); ?>/?cat="+dropdown.options[dropdown.selectedIndex].value;
		}
	}
	dropdown.onchange = onCatChange;
/* ]]> */
</script>

<?php
		} else {
?>
		<ul>
<?php
		$cat_args['title_li'] = '';
		wp_list_categories(apply_filters('widget_categories_args', $cat_args));
?>
		</ul>
<?php
		}

		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['count'] = !empty($new_instance['count']) ? 1 : 0;
		$instance['hierarchical'] = !empty($new_instance['hierarchical']) ? 1 : 0;
		$instance['dropdown'] = !empty($new_instance['dropdown']) ? 1 : 0;
		$instance['widget_width'] = $new_instance['widget_width'];

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => '') );
		$title = esc_attr( $instance['title'] );
		$count = isset($instance['count']) ? (bool) $instance['count'] :false;
		$hierarchical = isset( $instance['hierarchical'] ) ? (bool) $instance['hierarchical'] : false;
		$dropdown = isset( $instance['dropdown'] ) ? (bool) $instance['dropdown'] : false;
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('dropdown'); ?>" name="<?php echo $this->get_field_name('dropdown'); ?>"<?php checked( $dropdown ); ?> />
		<label for="<?php echo $this->get_field_id('dropdown'); ?>"><?php _e( 'Display as dropdown' ); ?></label><br />

		<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>"<?php checked( $count ); ?> />
		<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e( 'Show post counts' ); ?></label><br />

		<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('hierarchical'); ?>" name="<?php echo $this->get_field_name('hierarchical'); ?>"<?php checked( $hierarchical ); ?> />
		<label for="<?php echo $this->get_field_id('hierarchical'); ?>"><?php _e( 'Show hierarchy' ); ?></label></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}

}


/**
 * Tag cloud widget class
 *
 * @since 2.8.0
 */
class WP_Widget_Tag_Cloud_Custom extends WP_Widget {

	function WP_Widget_Tag_Cloud_Custom() {
		$widget_ops = array( 'description' => __( "Your most used tags in cloud format") );
		$this->WP_Widget('tag_cloud', __('Tag Cloud'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		$current_taxonomy = $this->_get_current_taxonomy($instance);
		if ( !empty($instance['title']) ) {
			$title = $instance['title'];
		} else {
			if ( 'post_tag' == $current_taxonomy ) {
				$title = __('Tags');
			} else {
				$tax = get_taxonomy($current_taxonomy);
				$title = $tax->labels->name;
			}
		}
		$title = apply_filters('widget_title', $title, $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $before_widget;
		
		?> <div class="<?php echo $widget_width; ?>"> <?php
		
		if ( $title )
			echo $before_title . $title . $after_title;
		echo '<div class="tagcloud">';
		wp_tag_cloud( apply_filters('widget_tag_cloud_args', array('taxonomy' => $current_taxonomy, 'format' => 'list', 'smallest' => 1, 'largest' => 1, 'unit' => 'em', 'orderby' => 'count' ) ) );
		echo "</div>\n";
		echo '</div>';
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance['title'] = strip_tags(stripslashes($new_instance['title']));
		$instance['taxonomy'] = stripslashes($new_instance['taxonomy']);
		$instance['widget_width'] = $new_instance['widget_width'];
		return $instance;
	}

	function form( $instance ) {
		$current_taxonomy = $this->_get_current_taxonomy($instance);
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
?>
	<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
	<input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php if (isset ( $instance['title'])) {echo esc_attr( $instance['title'] );} ?>" /></p>
	<p><label for="<?php echo $this->get_field_id('taxonomy'); ?>"><?php _e('Taxonomy:') ?></label>
	<select class="widefat" id="<?php echo $this->get_field_id('taxonomy'); ?>" name="<?php echo $this->get_field_name('taxonomy'); ?>">
	<?php foreach ( get_object_taxonomies('post') as $taxonomy ) :
				$tax = get_taxonomy($taxonomy);
				if ( !$tax->show_tagcloud || empty($tax->labels->name) )
					continue;
	?>
		<option value="<?php echo esc_attr($taxonomy) ?>" <?php selected($taxonomy, $current_taxonomy) ?>><?php echo $tax->labels->name; ?></option>
	<?php endforeach; ?>
	</select></p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
<?php
	}

	function _get_current_taxonomy($instance) {
		if ( !empty($instance['taxonomy']) && taxonomy_exists($instance['taxonomy']) )
			return $instance['taxonomy'];

		return 'post_tag';
	}
}

/**
 * Navigation Menu widget class
 */
class WP_Nav_Menu_Widget_Custom extends WP_Widget {

	function WP_Nav_Menu_Widget_Custom() {
		$widget_ops = array( 'description' => __('Add custom menus as a widget.') );
		parent::WP_Widget( 'nav_menu', __('Custom Menu'), $widget_ops );
	}

	function widget($args, $instance) {
		$nav_menu = wp_get_nav_menu_object( $instance['nav_menu'] );

		if ( !$nav_menu )
			return;

		$instance['title'] = apply_filters('widget_title', $instance['title'], $instance, $this->id_base);
		if ( !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		echo $args['before_widget'];
		
		?> <div class="<?php echo $widget_width; ?>"> <?php

		if ( !empty($instance['title']) )
			echo $args['before_title'] . $instance['title'] . $args['after_title'];

		wp_nav_menu( array( 'fallback_cb' => '', 'menu' => $nav_menu ) );

		echo '</div>';
		echo $args['after_widget'];
	}

	function update( $new_instance, $old_instance ) {
		$instance['title'] = strip_tags( stripslashes($new_instance['title']) );
		$instance['nav_menu'] = (int) $new_instance['nav_menu'];
		$instance['widget_width'] = $new_instance['widget_width'];
		return $instance;
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$nav_menu = isset( $instance['nav_menu'] ) ? $instance['nav_menu'] : '';

		$menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

		if ( !$menus ) {
			echo '<p>'. sprintf( __('No menus have been created yet. <a href="%s">Create some</a>.'), admin_url('nav-menus.php') ) .'</p>';
			return;
		}
		if ( !isset($instance['widget_width']) || !$widget_width = $instance['widget_width'] )
			$widget_width = 'one_first';
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('nav_menu'); ?>"><?php _e('Select Menu:'); ?></label>
			<select id="<?php echo $this->get_field_id('nav_menu'); ?>" name="<?php echo $this->get_field_name('nav_menu'); ?>">
		<?php
			foreach ( $menus as $menu ) {
				$selected = $nav_menu == $menu->term_id ? ' selected="selected"' : '';
				echo '<option'. $selected .' value="'. $menu->term_id .'">'. $menu->name .'</option>';
			}
		?>
			</select>
		</p>
		<p style="border-top:1px solid #dfdfdf; border-bottom:1px solid #dfdfdf; padding:10px 0; overflow:hidden;"><label for="<?php echo $this->get_field_id('widget_width'); ?>"><?php _e('Choose the width of widget:<br /><br />'); ?>
		<small style="color:#f00; float:right; padding-top:2px;">For horizontal sidebars</small>
		<select id="<?php echo $this->get_field_id('widget_width'); ?>" name="<?php echo $this->get_field_name('widget_width'); ?>" style="float:left;">
			<option<?php if ($widget_width == 'one_first'){ echo ' selected="selected"'; } ?> value="one_first">-- 1/1 --&nbsp;</option>
			<option<?php if ($widget_width == 'four_fifth'){ echo ' selected="selected"'; } ?> value="four_fifth">-- 4/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fourth'){ echo ' selected="selected"'; } ?> value="three_fourth">-- 3/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_third'){ echo ' selected="selected"'; } ?> value="two_third">-- 2/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'three_fifth'){ echo ' selected="selected"'; } ?> value="three_fifth">-- 3/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_half'){ echo ' selected="selected"'; } ?> value="one_half">-- 1/2 --&nbsp;</option>
			<option<?php if ($widget_width == 'two_fifth'){ echo ' selected="selected"'; } ?> value="two_fifth">-- 2/5 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_third'){ echo ' selected="selected"'; } ?> value="one_third">-- 1/3 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fourth'){ echo ' selected="selected"'; } ?> value="one_fourth">-- 1/4 --&nbsp;</option>
			<option<?php if ($widget_width == 'one_fifth'){ echo ' selected="selected"'; } ?> value="one_fifth">-- 1/5 --&nbsp;</option>
		</select>
		</label></p>
		<div style="clear:both;"></div>
		<?php
	}
}



function wp_custom_widgets_init() {
	if ( !is_blog_installed() )
		return;

	register_widget('WP_Widget_Custom_Flickr');
	register_widget('WP_Widget_Custom_Twitter');
	register_widget('WP_Widget_Custom_Recent_Comments');
	register_widget('WP_Widget_Custom_Popular_Posts');
	register_widget('WP_Widget_Custom_Recent_Posts');
	register_widget('WP_Widget_Custom_Recent_Testimonials');
	register_widget('WP_Widget_Custom_Recent_Products');
	register_widget('WP_Widget_Custom_Recent_Portfolio');
	register_widget('WP_Widget_Custom_Recent_Gallery');
	register_widget('WP_Widget_Custom_Contact_Info');
	register_widget('WP_Widget_Custom_Contact_Form');
	register_widget('WP_Widget_Custom_Advertisement');
	register_widget('WP_Widget_Custom_Video');
	register_widget('WP_Widget_Custom_HTML5_Video');
	register_widget('WP_Widget_Custom_HTML5_Audio');
	register_widget('WP_Widget_Custom_Divider');
	register_widget('WP_Widget_Pages_Custom');
	register_widget('WP_Widget_Links_Custom');
	register_widget('WP_Widget_Search_Custom');
	register_widget('WP_Widget_Archives_Custom');
	register_widget('WP_Widget_Meta_Custom');
	register_widget('WP_Widget_Calendar_Custom');
	register_widget('WP_Widget_Categories_Custom');
	register_widget('WP_Widget_Text_Custom');
	register_widget('WP_Widget_Tag_Cloud_Custom');
	register_widget('WP_Nav_Menu_Widget_Custom');

	do_action('widgets_init');
}

add_action('init', 'wp_custom_widgets_init', 1);
